Source-Changes-HG archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

[src/trunk]: src/sys/arch/arm/include Provide size_t.



details:   https://anonhg.NetBSD.org/src/rev/7cee93ad984e
branches:  trunk
changeset: 336668:7cee93ad984e
user:      joerg <joerg%NetBSD.org@localhost>
date:      Mon Mar 09 11:03:19 2015 +0000

description:
Provide size_t.

diffstat:

 sys/arch/arm/include/sysarch.h |  10 ++++++++--
 1 files changed, 8 insertions(+), 2 deletions(-)

diffs (30 lines):

diff -r 3e000dcfbd12 -r 7cee93ad984e sys/arch/arm/include/sysarch.h
--- a/sys/arch/arm/include/sysarch.h    Mon Mar 09 03:43:02 2015 +0000
+++ b/sys/arch/arm/include/sysarch.h    Mon Mar 09 11:03:19 2015 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: sysarch.h,v 1.11 2014/01/16 21:48:41 matt Exp $        */
+/*     $NetBSD: sysarch.h,v 1.12 2015/03/09 11:03:19 joerg Exp $       */
 
 /*
  * Copyright (c) 1996-1997 Mark Brinicombe.
@@ -38,13 +38,19 @@
 #include <sys/cdefs.h>
 
 /*
  * Pickup definition of uintptr_t
  */
+#include <machine/ansi.h>
 #include <sys/stdint.h>
 #ifndef _KERNEL
 #include <stdbool.h>
 #endif
 
+#ifdef _BSD_SIZE_T_
+typedef        _BSD_SIZE_T_ size_t;
+#undef _BSD_SIZE_T_
+#endif
+
 /*
  * Architecture specific syscalls (arm)
  */
@@ -38,13 +38,19 @@
 
 /*
- * Pickup definition of uintptr_t
+ * Pickup definition of size_t and uintptr_t
  */



Home | Main Index | Thread Index | Old Index